==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>正在录制视频，是否关闭？</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>您没有权限操作此文件夹</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>文件夹无效</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>基本设置</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>保存路径</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>拍照设置</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>连拍</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>拍照延时设置</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>输出设置</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>输出格式</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4张</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10张</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>相机</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>相机是一款简单易用的摄像头应用工具，可实现拍照、录制视频等功能。</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>文件未保存</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>存储位置：</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>照片：</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>视频：</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>分辨率设置</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>分辨率：</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>拍照</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>录制视频</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>结束拍照</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>未连接摄像头</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>摄像头已被占用</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>结束录制</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.3.9.orig.tar.xz: deepin-camera-1.3.9/src/translations/deepin-camera_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>正在录制视频，是否关闭？</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">打开文件夹</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>拍照</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>切换摄像头</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>您没有权限操作此文件夹</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">文件夹无效</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>基本设置</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>保存路径</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>拍照设置</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>连拍</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>拍照延时设置</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>输出设置</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>输出格式</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4张</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10张</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>相机</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>相机是一款简单易用的摄像头应用工具，可实现拍照、录制视频等功能。</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>文件未保存</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">存储位置：</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>照片：</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>视频：</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>分辨率设置</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>分辨率：</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>照片存储位置：</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>视频存储位置：</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>音效</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>镜像摄像头</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>闪光灯</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>构图网格</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>十字网格</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>井字网格</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>相机</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>结束录制</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>结束拍照</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>唤起右键菜单</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">拍照</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">录制视频</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">结束拍照</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>标准</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>鲜明</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>暖色</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>冷色</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>复古</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>冲印</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>灰度</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>黑白</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>闪光灯</translation>
    </message>
    <message>
        <source>On</source>
        <translation>开启</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>延时拍摄</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>滤镜</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>曝光</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>未连接摄像头</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>摄像头已被占用</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">结束录制</translation>
    </message>
</context>
</TS>
